==> qucs_0.0.5.orig.tar.gz: qucs-0.0.5.orig/qucs-core/src/components/vccs.cpp <==
/*
 * vccs.cpp - vccs class implementation
 *
 * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this package; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.  
 *
 * $Id: vccs.cpp,v 1.10 2005/01/24 19:37:17 raimi Exp $
 *
 */

#if HAVE_CONFIG_H
# include <config.h>
#endif

#define __USE_BSD
#define __USE_XOPEN
#include <stdio.h>
#include <stdlib.h>

#include "complex.h"
#include "object.h"
#include "node.h"
#include "circuit.h"
#include "component_id.h"
#include "constants.h"
#include "vccs.h"

vccs::vccs () : circuit (4) {
  type = CIR_VCCS;
#if AUGMENTED
  setVoltageSources (1);
#endif
}

void vccs::calcSP (nr_double_t frequency) {
  nr_double_t g = getPropertyDouble ("G") * z0;
  nr_double_t t = getPropertyDouble ("T");

  complex z1 = polar (2.0 * g, M_PI - 2.0 * M_PI * frequency * t);
  complex z2 = polar (2.0 * g, - 2.0 * M_PI * frequency * t);

  setS (1, 1, 1.0); setS (1, 2, 0.0); setS (1, 3, 0.0); setS (1, 4, 0.0);
  setS (2, 1, z1);  setS (2, 2, 1.0); setS (2, 3, 0.0); setS (2, 4, z2);
  setS (3, 1, z2);  setS (3, 2, 0.0); setS (3, 3, 1.0); setS (3, 4, z1);
  setS (4, 1, 0.0); setS (4, 2, 0.0); setS (4, 3, 0.0); setS (4, 4, 1.0);
}

void vccs::initDC (void) {
  allocMatrixMNA ();
#if AUGMENTED
  setC (1, 1, +1.0); setC (1, 2, +0.0); setC (1, 3, +0.0); setC (1, 4, -1.0);
  setB (1, 1, +0.0); setB (2, 1, +1.0); setB (3, 1, -1.0); setB (4, 1, +0.0);
  setD (1, 1, -1.0 / getPropertyDouble ("G"));
  setE (1, +0.0);
#else
  nr_double_t g = getPropertyDouble ("G");
  setY (2, 1, +g); setY (3, 4, +g);
  setY (3, 1, -g); setY (2, 4, -g);
#endif
}

void vccs::initAC (void) {
  initDC ();
}

void vccs::calcAC (nr_double_t frequency) {
  nr_double_t t = getPropertyDouble ("T");
#if AUGMENTED
  nr_double_t g = getPropertyDouble ("G");
  complex r = polar (1.0 / g, - 2.0 * M_PI * frequency * t);
  setD (1, 1, -r);
#else
  complex g = polar (getPropertyDouble ("G"), - 2.0 * M_PI * frequency * t);
  setY (2, 1, +g); setY (3, 4, +g);
  setY (3, 1, -g); setY (2, 4, -g);
#endif
}

==> qucs_0.0.7.orig.tar.gz: qucs-0.0.7.orig/qucs-core/src/components/vccs.cpp <==
/*
 * vccs.cpp - vccs class implementation
 *
 * Copyright (C) 2003, 2004, 2005 Stefan Jahn <stefan@lkcc.org>
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this package; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
 * Boston, MA 02110-1301, USA.  
 *
 * $Id: vccs.cpp,v 1.12 2005/06/02 18:17:52 raimi Exp $
 *
 */

#if HAVE_CONFIG_H
# include <config.h>
#endif

#define __USE_BSD
#define __USE_XOPEN
#include <stdio.h>
#include <stdlib.h>

#include "complex.h"
#include "object.h"
#include "node.h"
#include "circuit.h"
#include "component_id.h"
#include "constants.h"
#include "vccs.h"

vccs::vccs () : circuit (4) {
  type = CIR_VCCS;
#if AUGMENTED
  setVoltageSources (1);
#endif
}

void vccs::calcSP (nr_double_t frequency) {
  nr_double_t g = getPropertyDouble ("G") * z0;
  nr_double_t t = getPropertyDouble ("T");

  complex z1 = polar (2.0 * g, M_PI - 2.0 * M_PI * frequency * t);
  complex z2 = polar (2.0 * g, - 2.0 * M_PI * frequency * t);

  setS (NODE_1, NODE_1, 1.0); setS (NODE_1, NODE_2, 0.0);
  setS (NODE_1, NODE_3, 0.0); setS (NODE_1, NODE_4, 0.0);
  setS (NODE_2, NODE_1, z1);  setS (NODE_2, NODE_2, 1.0);
  setS (NODE_2, NODE_3, 0.0); setS (NODE_2, NODE_4, z2);
  setS (NODE_3, NODE_1, z2);  setS (NODE_3, NODE_2, 0.0);
  setS (NODE_3, NODE_3, 1.0); setS (NODE_3, NODE_4, z1);
  setS (NODE_4, NODE_1, 0.0); setS (NODE_4, NODE_2, 0.0);
  setS (NODE_4, NODE_3, 0.0); setS (NODE_4, NODE_4, 1.0);
}

void vccs::initDC (void) {
  allocMatrixMNA ();
#if AUGMENTED
  setC (VSRC_1, NODE_1, +1.0); setC (VSRC_1, NODE_2, +0.0);
  setC (VSRC_1, NODE_3, +0.0); setC (VSRC_1, NODE_4, -1.0);
  setB (NODE_1, VSRC_1, +0.0); setB (NODE_2, VSRC_1, +1.0);
  setB (NODE_3, VSRC_1, -1.0); setB (NODE_4, VSRC_1, +0.0);
  setD (VSRC_1, VSRC_1, -1.0 / getPropertyDouble ("G"));
  setE (VSRC_1, +0.0);
#else
  nr_double_t g = getPropertyDouble ("G");
  setY (NODE_2, NODE_1, +g); setY (NODE_3, NODE_4, +g);
  setY (NODE_3, NODE_1, -g); setY (NODE_2, NODE_4, -g);
#endif
}

void vccs::initAC (void) {
  initDC ();
}

void vccs::calcAC (nr_double_t frequency) {
  nr_double_t t = getPropertyDouble ("T");
#if AUGMENTED
  nr_double_t g = getPropertyDouble ("G");
  complex r = polar (1.0 / g, - 2.0 * M_PI * frequency * t);
  setD (VSRC_1, 1, -r);
#else
  complex g = polar (getPropertyDouble ("G"), - 2.0 * M_PI * frequency * t);
  setY (NODE_2, NODE_1, +g); setY (NODE_3, NODE_4, +g);
  setY (NODE_3, NODE_1, -g); setY (NODE_2, NODE_4, -g);
#endif
}
